#include <iostream>
#include <vector>

using namespace std;

const long long INF = 1000000000000000000LL;

struct SegTree {
    int sz;
    vector<int> it;

    SegTree(int sz) : sz(sz) {
        it.resize(4 * sz);
    }

    void add(int u, int L, int R, int i, int v) {
        if (R - L == 1) {
            it[u] += v;
            return;
        }
        int M = (L + R) / 2;
        if (i < M) {
            add(2 * u + 1, L, M, i, v);
        } else {
            add(2 * u + 2, M, R, i, v);
        }
        it[u] = it[2 * u + 1] + it[2 * u + 2];
    }

    int get(int u, int L, int R, int l, int r) {
        if (l >= R || L >= r) {
            return 0;
        }
        if (l <= L && R <= r) {
            return it[u];
        }
        int M = (L + R) / 2;
        return get(2 * u + 1, L, M, l, r) + get(2 * u + 2, M, R, l, r);
    }
};

int main() {
    ios::sync_with_stdio(0);
    cin.tie(0);

    int n;
    cin >> n;
    vector<int> a(n);
    for (int i = 0; i < n; i++) {
        cin >> a[i];
        --a[i];
    }
    vector<int> b(n);
    for (int i = 0; i < n; i++) {
        b[a[i]] = i;
    }

    vector<long long> cntl(n), cntr(n);
    SegTree stl(n);
    for (int i = 0; i < n; i++) {
        cntl[i] = stl.get(0, 0, n, b[i] + 1, n);
        stl.add(0, 0, n, b[i], 1);
        if (i > 0) {
            cntl[i] += cntl[i - 1];
        }
    }
    SegTree str(n);
    for (int i = n - 1; i >= 0; i--) {
        cntr[i] = str.get(0, 0, n, 0, b[i]);
        str.add(0, 0, n, b[i], 1);
        if (i < n - 1) {
            cntr[i] += cntr[i + 1];
        }
    }

    long long best = INF;
    for (int i = 0; i < n; i++) {
        best = min(best, (i > 0 ? cntl[i - 1] : 0) + (i < n - 1 ? cntr[i + 1] : 0));
    }

    cout << best << endl;

    return 0;
}
